# StoreGPS.py
# Server www.java-online.eu

import serial
from math import exp, cos
from sim800 import SIM800
from time import sleep
from sys import exit

port = "/dev/ttyUSB0"  # USB adapter

def parseGPS(data):
#    print "raw:", data
    if data[0:6] == "$GPGGA":
        s = data.split(",")
        if s[7] == '0':
            print "no satellite data available"
            return None       
        time = int(s[1][0:2]) + int(s[1][2:4]) / 60.0 + int(s[1][4:6]) / 3600.0
        lat = s[2]
        lon = s[4]
        return time, lat, lon
    return None

gpsSer = serial.Serial(port, baudrate = 9600, timeout = 0.5)

APN = "internet" # Sim card from Salt. 
HOST = "www.java-online.eu"
PORT = 80
table = "data01"

gsm = SIM800(verbose = False)

print "Resetting modem..."
if not gsm.reset():
   print "Modem not responding."
   exit(0)
   
print "OK. Registering to provider..."
if not gsm.checkRegistration():
   print "Registration to provider failed."
   exit(0)

print "OK. Login to provider..."
if not gsm.login(APN):
   print "Login failed."
   exit(0)

print "OK. Bringing up network..."
if not gsm.startNetwork():
   print "Network failed."
   exit(0)

print "Got IP address", gsm.getIPAddress()

x = 0
dt = 5
maxRetries = 5
while True:
    value = None
    while value == None:
        data = gpsSer.readline()
        value = parseGPS(data)
    t = value[0]    
    x = value[1]
    y = value[2]
    print("Data (t, x, y) = (" + str(t) + ", "  + str(x) + ", " + str(y) + ")")
    retry = 0
    while retry < maxRetries:
        reply = gsm.connectTCP(HOST, PORT)
        if "OK" in reply:
            break
        retry += 1
        print "Connection failed. Retry #", retry
        sleep(2)
        if retry == maxRetries:
            print "Reached maximum retries. Terminating program"
            exit(0)
    print "Sending HTTP request..."    
    gsm.sendHTTPRequest(HOST, "/raspiremote/insert.php?table=" + table + "&x=" + str(t) + "&y=" + str(y)) 
    print "Closing. Waiting for next data..."
    gsm.closeTCP()
    sleep(dt)
