# WebController2.py
# Minimal version using a state handler
# Necessary to avoid a worker thread 
# if time consuming code has to be executed or 
# just to make the server inactive until some
# sensors are ready again.

from tcpcom import HTTPServer
import RPi.GPIO as GPIO

P_LED = 22

def setup():
    GPIO.setmode(GPIO.BOARD)
    GPIO.setup(P_LED, GPIO.OUT)

html = """<!DOCTYPE html>
<html>
  <head> <title>Raspi Remote</title> 
  <meta name="viewport" content="width=device-width, initial-scale=1">
  </head>
  <body> 
     <h1>Raspberry Pi Controller</h1>
     <b>Press to change state of LED:</b>
     <form method="get">
       <input type="submit" style="font-size: 50px; height: 100px; width: 150px" name="LED" value="ON" />
       <input type="submit" style="font-size: 50px; height: 100px; width: 150px" name="LED" value="OFF" />
     </form>
     <br>
     Current LED state: %s
  </body>
</html>
"""

def setLed(state):
    if state == "ON":
        GPIO.output(P_LED, GPIO.HIGH)
    else:
        GPIO.output(P_LED, GPIO.LOW)
        
def stateHandler():    
    setLed(state)
    
def requestHandler(clientIP, filename, params):
    global state
    if len(params) > 0:
        state = params[0][1]
    text = html % (state)
    return text, stateHandler

setup()
state = "OFF"
setLed(state)
print "Server listening at IP " + HTTPServer.getIPAddress() + ":80"             
server = HTTPServer(requestHandler)
server.loopForever()
setLed("OFF")
GPIO.cleanup()
print "Terminated"
